@@ -13,5 +13,5 @@ from .encryption_and_decryption import EncDec #加解密
 from .mysql import mysql_class #mysql包
 # from .translations.baidu_translate import *
 # from .translations.google_translate import *
-from .nlp import nlp_tools
+# from .nlp.nlp_tools import nlp_tool
 from .es import EsOp #es
\ No newline at end of file
