@@ -10,9 +10,10 @@ Date: 2021/2/9 下午3:47
 
 import configparser
 import os
+import sys
 
 def get_cf_path(configname = None):
-    curpath = os.path.abspath(os.path.dirname(__file__))
+    curpath = sys.path[0]
     while curpath != '/':
         for file in os.listdir(curpath):
             if configname != None:
@@ -41,6 +42,6 @@ class configuration(object):
 
 if __name__ == '__main__':
     obj = configuration()
-    item = obj.get_label('hot_mysql')
-    value = obj.get_label_value('hot_mysql','port')
-    print(item,value)
\ No newline at end of file
+    item = obj.get_label('es')
+    value = obj.get_label_value('es','host')
+    print(item,value)
