@@ -101,7 +101,6 @@ class EsOp():
 
     def index_result_dict(self,result):
         if result:
-            print(result)
             items = result['hits']['hits']
             result_list= []
             for i in items:
@@ -127,7 +126,13 @@ class EsOp():
         result = self.conn.search(index=index_name,doc_type=doc_type, body=body)
         return self.index_result_dict(result)
     def index_search_absolute_match(self,index_name,query_dict,pn=1,size=10,doc_type=''):
-        iterator = Search(using=self.client, doc_type=doc_type, index=index_name).query("term", **query_dict)[(pn - 1) * size:pn*size]
+        new_dict= {}
+        for i in query_dict.keys():
+            if i == '_id':
+                new_dict[i] = query_dict[i]
+            else:
+                new_dict[i+'.keyword'] =query_dict[i]
+        iterator = Search(using=self.client, doc_type=doc_type, index=index_name).query("term", **new_dict)[(pn - 1) * size:pn*size]
         iterator = iterator.execute().to_dict()
         return self.index_result_dict(iterator)
 
@@ -160,11 +165,11 @@ if __name__ == '__main__':
     # }]
     # es.bulk_to_es('standard_platform',rows)
     #全量
-    # s = es.index_search_all('standard_platform')
+    # s = es.index_search_all('standard_search')
     # print(s)
-    # s= es.index_search_absolute_match('standard_platform',{'question': '醉了1'})
-    # print(s)
-    s = es.index_search_fuzzy_match('standard_data',{'question': '电动车的最大限速是多少'},pn=1,size=10)
+    s= es.index_search_absolute_match('standard_search',{'CnName': '氟硅酸钠的化学分析方法'})
+    print(s)
+    s = es.index_search_fuzzy_match('title_index_search',{'word': '成品'},pn=1,size=10)
     print(s)
     # s = es.index_MultiMatch('standard_platform','1',['question','answer'])
     # print(s)
